import React, { Children, cloneElement, useEffect, useRef } from 'react';
import { StyleSheet, ScrollView, View, Text } from 'react-native';
import { Theme } from '../../components/Styles/theme';
let timer = null;
let autoplayTimer = null;
const Swiper = props => {
    const { children, width, current = 0, indicatorMode = 'round', indicatorPosition = 'bottomCenter', autoplay = false, interval = 2500, 
    // duration = 500,
    // circular = true,
    borderRadius = 8, backgroundColor, onChange, } = props;
    const swiperItemNumber = [].concat(children).length;
    const $scroll = useRef(null);
    useEffect(() => {
        if (!autoplay) {
            autoplayTimer && clearInterval(autoplayTimer);
        }
        else {
            autoplayTimer = setInterval(() => {
                let index = current + 1;
                if (index >= swiperItemNumber) {
                    index = 0;
                }
                $scroll?.current &&
                    $scroll.current.scrollTo({
                        x: index * width,
                        animated: true,
                    });
                onChange && onChange(index);
            }, interval);
        }
        return () => {
            autoplayTimer && clearInterval(autoplayTimer);
        };
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [autoplay, interval, current]);
    const getPanes = () => {
        const newChildren = [];
        Children.map(children, (child, idx) => {
            newChildren.push(cloneElement(child, {
                key: idx,
                width,
                borderRadius,
            }));
        });
        return newChildren;
    };
    const renderIndicator = () => {
        const top = ['topLeft', 'topCenter', 'topRight'].includes(indicatorPosition);
        const left = ['topLeft', 'bottomLeft'].includes(indicatorPosition);
        const center = ['topCenter', 'bottomCenter'].includes(indicatorPosition);
        const right = ['topRight', 'bottomRight'].includes(indicatorPosition);
        const isNumber = indicatorMode === 'number';
        const isRound = indicatorMode === 'round';
        const isRect = indicatorMode === 'rect';
        const isDot = indicatorMode === 'dot';
        if (indicatorMode === 'none') {
            return null;
        }
        return (React.createElement(View, { style: [
                styles.indicatorWrap,
                top ? styles.wrapTop : styles.wrapBottom,
                left && styles.wrapLeft,
                center && styles.wrapCenter,
                right && styles.wrapRight,
            ] },
            isNumber && (React.createElement(View, { style: [styles.indicator, styles.indicatorNumber] },
                React.createElement(Text, { style: styles.indicatorNumberText },
                    current + 1,
                    "/",
                    swiperItemNumber))),
            (isRound || isRect || isDot) && (React.createElement(View, { style: [styles.indicator] }, new Array(swiperItemNumber).fill(1).map((_, index) => {
                return (React.createElement(View, { key: index, style: [
                        styles.indicatorItem,
                        index === current && styles.active,
                        isDot && styles.indicatorItemDot,
                        isRect && styles.indicatorItemRect,
                    ] }));
            })))));
    };
    const onScrollEnd = (event) => {
        event.persist();
        if (timer) {
            clearTimeout(timer);
        }
        timer = setTimeout(() => {
            const { contentOffset, layoutMeasurement } = event.nativeEvent;
            const { x } = contentOffset;
            const { width: w } = layoutMeasurement;
            const index = Math.round(x / w);
            onChange && onChange(index);
        }, 20);
    };
    return (React.createElement(View, { style: { width } },
        React.createElement(ScrollView, { horizontal: true, pagingEnabled: true, alwaysBounceHorizontal: true, ref: $scroll, showsHorizontalScrollIndicator: false, onMomentumScrollEnd: onScrollEnd, style: {
                width,
                borderRadius,
                backgroundColor,
            } }, getPanes()),
        renderIndicator()));
};
const styles = StyleSheet.create({
    container: {
        overflow: 'hidden',
    },
    indicatorWrap: {
        position: 'absolute',
        left: '10%',
        right: '10%',
        flexDirection: 'row',
        alignItems: 'center',
    },
    wrapTop: {
        top: '10%',
    },
    wrapBottom: {
        bottom: '10%',
    },
    wrapLeft: {
        justifyContent: 'flex-start',
    },
    wrapCenter: {
        justifyContent: 'center',
    },
    wrapRight: {
        justifyContent: 'flex-end',
    },
    indicator: {
        flexDirection: 'row',
        alignItems: 'center',
    },
    indicatorItem: {
        width: 8,
        height: 8,
        borderRadius: 4,
        backgroundColor: Theme.fillMask,
        marginLeft: 6,
    },
    active: {
        width: 16,
        backgroundColor: Theme.fillBase,
    },
    indicatorNumber: {
        backgroundColor: Theme.fillMask,
        paddingHorizontal: 8,
        paddingVertical: 1,
        borderRadius: 10,
    },
    indicatorNumberText: {
        color: Theme.colorTextBaseInverse,
        fontSize: 12,
    },
    indicatorItemRect: {
        width: 16,
        height: 4,
        borderRadius: 0,
    },
    indicatorItemDot: {
        width: 8,
    },
});
export default Swiper;
